==> countdl.php?fileurl=http%3A%2F%2Fwww.squirrelmail.org%2Fplugins%2Fblock_attach.0.4-1.4.0.tar.gz: block_attach/includes/display_save.php <==
<?
/*******************************************************************************

    Author ......... Jimmy Conner
    Contact ........ jimmy@advcs.org
    Home Site ...... http://www.advcs.org/
    Program ........ Block Attachments
    Version ........ 0.4
    Purpose ........ Allows an admin to block any types of attachments

*******************************************************************************/

      global $blocked, $filename, $_POST;
      if (isset($_POST['exu'])) {
         $exu = strtolower(strip_tags($_POST['exu']));
         if (strlen($exu) > 0 && !in_array($exu,$excluded)) {
            $excluded[] = $exu;
            CreateBlockedArray($blocked,$warning,$excluded,$virusscan,$virusscanupdate,$filename);
            Header("Location: " . SM_PATH . "plugins/block_attach/options.php");
         }
      }

      if (isset($_POST['newb'])) {
         $give = strip_tags($_POST['give']);
         $newb = strtolower(strip_tags($_POST['newb']));
         $s = "abcdefghijklmnopqrstuvwxyz1234567890_";
         for ($a = 0; $a < strlen($newb); $a++) {
            $pos = strpos($s, substr($newb,$a,1));
            if ($pos === false) {
               $newb = str_replace(substr($newb,$a,1),'',$newb);
               $a--;
            }
         }
         if (strlen($newb) > 0 && !in_array($newb,$blocked) && !in_array($newb,$warning) && $give == "block") {
            $blocked[] = $newb;
            CreateBlockedArray($blocked,$warning,$excluded,$virusscan,$virusscanupdate,$filename);
         }
         if (strlen($newb) > 0 && !in_array($newb,$blocked) && !in_array($newb,$warning) && $give == "warning") {
            $warning[] = $newb;
            CreateBlockedArray($blocked,$warning,$excluded,$virusscan,$virusscanupdate,$filename);
         }
         Header("Location: " . SM_PATH . "plugins/block_attach/options.php");
      }

      if (isset($_POST['btypes'])) {
         $btypes = strip_tags($_POST['btypes']);
         for ($a = 0; $a < count($blocked); $a++) {
            if ($blocked[$a] == $btypes)
               unset($blocked[$a]);
         }
         CreateBlockedArray($blocked,$warning,$excluded,$virusscan,$virusscanupdate,$filename);
         Header("Location: " . SM_PATH . "plugins/block_attach/options.php");
      }

      if (isset($_POST['wtypes'])) {
         $wtypes = strip_tags($_POST['wtypes']);
         for ($a = 0; $a < count($warning); $a++) {
            if ($warning[$a] == $wtypes)
               unset($warning[$a]);
         }
         CreateBlockedArray($blocked,$warning,$excluded,$virusscan,$virusscanupdate,$filename);
         Header("Location: " . SM_PATH . "plugins/block_attach/options.php");
      }

      if (isset($_POST['exclude'])) {
         $exclude = strip_tags($_POST['exclude']);
         for ($a = 0; $a < count($excluded); $a++) {
            if ($excluded[$a] == $exclude)
               unset($excluded[$a]);
         }
         CreateBlockedArray($blocked,$warning,$excluded,$virusscan,$virusscanupdate,$filename);
         Header("Location: " . SM_PATH . "plugins/block_attach/options.php");
      }

      if (isset($_POST['vscan'])) {
         $vscan = strip_tags($_POST['vscan']);
         CreateBlockedArray($blocked,$warning,$excluded,$vscan,$virusscanupdate,$filename);
         Header("Location: " . SM_PATH . "plugins/block_attach/options.php");
      }

      if (isset($_POST['vscanupdate'])) {
         $vscanupdate = strip_tags($_POST['vscanupdate']);
         CreateBlockedArray($blocked,$warning,$excluded,$vscan,$vscanupdate,$filename);
         Header("Location: " . SM_PATH . "plugins/block_attach/options.php");
      }

?>

==> countdl.php?fileurl=http%3A%2F%2Fwww.squirrelmail.org%2Fplugins%2Fblock_attach.0.5-1.4.0.tar.gz: block_attach/includes/display_save.php <==
<?
/*******************************************************************************

    Author ......... Jimmy Conner
    Contact ........ jimmy@advcs.org
    Home Site ...... http://www.advcs.org/
    Program ........ Block Attachments
    Version ........ 0.5
    Purpose ........ Allows an admin to block any types of attachments

*******************************************************************************/

      global $blocked, $filename, $_POST;
      if (isset($_POST['exu'])) {
         $exu = strtolower(strip_tags($_POST['exu']));
         if (strlen($exu) > 0 && !in_array($exu,$excluded)) {
            $excluded[] = $exu;
            CreateBlockedArray($blocked,$warning,$excluded,$filename);
            Header("Location: " . SM_PATH . "plugins/block_attach/options.php");
         }
      }

      if (isset($_POST['newb'])) {
         $give = strip_tags($_POST['give']);
         $newb = strtolower(strip_tags($_POST['newb']));
         $s = "abcdefghijklmnopqrstuvwxyz1234567890_";
         for ($a = 0; $a < strlen($newb); $a++) {
            $pos = strpos($s, substr($newb,$a,1));
            if ($pos === false) {
               $newb = str_replace(substr($newb,$a,1),'',$newb);
               $a--;
            }
         }
         if (strlen($newb) > 0 && !in_array($newb,$blocked) && !in_array($newb,$warning) && $give == "block") {
            $blocked[] = $newb;
            CreateBlockedArray($blocked,$warning,$excluded,$filename);
         }
         if (strlen($newb) > 0 && !in_array($newb,$blocked) && !in_array($newb,$warning) && $give == "warning") {
            $warning[] = $newb;
            CreateBlockedArray($blocked,$warning,$excluded,$filename);
         }
         Header("Location: " . SM_PATH . "plugins/block_attach/options.php");
      }

      if (isset($_POST['btypes'])) {
         $btypes = strip_tags($_POST['btypes']);
         for ($a = 0; $a < count($blocked); $a++) {
            if ($blocked[$a] == $btypes)
               unset($blocked[$a]);
         }
         CreateBlockedArray($blocked,$warning,$excluded,$filename);
         Header("Location: " . SM_PATH . "plugins/block_attach/options.php");
      }

      if (isset($_POST['wtypes'])) {
         $wtypes = strip_tags($_POST['wtypes']);
         for ($a = 0; $a < count($warning); $a++) {
            if ($warning[$a] == $wtypes)
               unset($warning[$a]);
         }
         CreateBlockedArray($blocked,$warning,$excluded,$filename);
         Header("Location: " . SM_PATH . "plugins/block_attach/options.php");
      }

      if (isset($_POST['exclude'])) {
         $exclude = strip_tags($_POST['exclude']);
         for ($a = 0; $a < count($excluded); $a++) {
            if ($excluded[$a] == $exclude)
               unset($excluded[$a]);
         }
         CreateBlockedArray($blocked,$warning,$excluded,$filename);
         Header("Location: " . SM_PATH . "plugins/block_attach/options.php");
      }

?>
